@@ -2,9 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import work
-from . import routing
-from . import timesheet
+
+from . import routing, timesheet, work
 
 
 def register():
